==> share-file-systems-0.2.20.tgz: package/js/lib/terminal/commands/library/typescript.js <==
/* lib/terminal/commands/library/typescript - Executes TypeScript type checks. */ import { exec } from "child_process";
import { stat } from "fs";
import { EOL } from "os";
import error from "../../utilities/error.js";
import log from "../../utilities/log.js";
import vars from "../../utilities/vars.js";
const typescript = function terminal_commands_library_typescript(typepath, callback) {
    const errorOut = function terminal_commands_library_typescript_stat_errorOut(message, errorObject) {
        const err = errorObject === null ? [
            vars.text.angry + message + vars.text.none
        ] : [
            vars.text.angry + message + vars.text.none,
            JSON.stringify(errorObject)
        ];
        error(err);
        process.exit(1);
    };
    if (typeof typepath !== "string" || typepath.length < 1) {
        typepath = vars.path.project;
    }
    stat(typepath, function terminal_commands_library_typescript_stat(statError, stat) {
        if (statError === null) {
            const dir = stat.isDirectory();
            if (dir === true) {
                const command = `npx tsc --pretty --noEmit --project ${vars.path.project}tsconfig.json`, args = {
                    cwd: typepath
                };
                exec(command, args, function terminal_commands_library_typescript_stat_exec(err, stdout) {
                    const control = "\u001b[91m";
                    if (stdout !== "") {
                        let compileErrors = stdout.slice(stdout.indexOf("Found"));
                        if (stdout.indexOf(` ${control}error${vars.text.none} `) > -1) {
                            errorOut([
                                "TypeScript reported warnings.",
                                stdout
                            ].join(EOL), null);
                            return;
                        }
                        compileErrors = compileErrors.slice(0, compileErrors.indexOf("error") - 1).replace(/\D+/g, "");
                        if (vars.environment.command === "build") {
                            log([
                                stdout
                            ]);
                            callback("TypeScript", [
                                compileErrors
                            ], false);
                        } else {
                            callback("TypeScript", [
                                stdout
                            ], true);
                        }
                    } else {
                        callback("TypeScript", [
                            `${vars.text.green + vars.text.bold}TypeScript type validation completed without warnings.${vars.text.none}`
                        ], false);
                    }
                });
            } else {
                errorOut("The TypeScript command is only supporting directory type file system paths.", null);
            }
        } else {
            errorOut(`Error accessing path: ${typepath}`, statError);
        }
    });
};
export default typescript;

==> share-file-systems-0.2.23.tgz: package/js/lib/terminal/commands/library/typescript.js <==
/* lib/terminal/commands/library/typescript - Executes TypeScript type checks. */ import { exec } from "child_process";
import { stat } from "fs";
import { EOL } from "os";
import error from "../../utilities/error.js";
import log from "../../utilities/log.js";
import vars from "../../utilities/vars.js";
const typescript = function terminal_commands_library_typescript(typePath, callback) {
    const errorOut = function terminal_commands_library_typescript_stat_errorOut(message, errorObject) {
        const err = errorObject === null ? [
            vars.text.angry + message + vars.text.none
        ] : [
            vars.text.angry + message + vars.text.none,
            JSON.stringify(errorObject)
        ];
        error(err);
        process.exit(1);
    };
    if (typeof typePath !== "string" || typePath.length < 1) {
        typePath = vars.path.project;
    }
    stat(typePath, function terminal_commands_library_typescript_stat(statError, stat) {
        if (statError === null) {
            const dir = stat.isDirectory();
            if (dir === true) {
                const command = `npx tsc --pretty --noEmit --project ${vars.path.project}tsconfig.json`, args = {
                    cwd: typePath
                };
                exec(command, args, function terminal_commands_library_typescript_stat_exec(err, stdout) {
                    const control = "\u001b[91m";
                    if (stdout !== "") {
                        let compileErrors = stdout.slice(stdout.indexOf("Found"));
                        if (stdout.indexOf(` ${control}error${vars.text.none} `) > -1) {
                            errorOut([
                                "TypeScript reported warnings.",
                                stdout
                            ].join(EOL), null);
                            return;
                        }
                        compileErrors = compileErrors.slice(0, compileErrors.indexOf("error") - 1).replace(/\D+/g, "");
                        if (vars.environment.command === "build") {
                            log([
                                stdout
                            ]);
                            callback("TypeScript", [
                                compileErrors
                            ], false);
                        } else {
                            callback("TypeScript", [
                                stdout
                            ], true);
                        }
                    } else {
                        callback("TypeScript", [
                            `${vars.text.green + vars.text.bold}TypeScript type validation completed without warnings.${vars.text.none}`
                        ], false);
                    }
                });
            } else {
                errorOut("The TypeScript command is only supporting directory type file system paths.", null);
            }
        } else {
            errorOut(`Error accessing path: ${typePath}`, statError);
        }
    });
};
export default typescript;
